-- The addon namespace.
local addon, ns = ...

-- Define the RandomBackground class and put it in the addon namespace.
local RandomBackground = {}
local RandomBackgroundMetatable = { __index = RandomBackground }
ns.RandomBackground = RandomBackground

-- Constructor.
function RandomBackground:new(parent, x, y)
	local self = {} 
	setmetatable(self, RandomBackgroundMetatable)
	
	self.Current = 1
	self.Scale = 1
	
	self.Texture = parent:CreateTexture(nil, "ARTWORK")
	self.Texture:SetPoint("CENTER", parent, "CENTER", x, y)
	self.Texture:Hide()
	
	return self
end

-- Shows the background if the percentage is greater than 0.
function RandomBackground:Update(percentage)
	self:Hide()
	if percentage > 0 and HeartbeatConfig.showBackground then
		self:Show()
	end
end

-- Hides the texture.
function RandomBackground:Hide()
	self.Texture:Hide()
end

-- Shows a "random" texture.
function RandomBackground:Show()
	self.Texture:SetWidth((self.Coordinates[self.Current][2] - self.Coordinates[self.Current][1]) * self.ScaleX)
	self.Texture:SetHeight((self.Coordinates[self.Current][4] - self.Coordinates[self.Current][3]) * self.ScaleY)
	local left = self.Coordinates[self.Current][1] / self.TextureWidth
	local right = self.Coordinates[self.Current][2] / self.TextureWidth
	local top = self.Coordinates[self.Current][3] / self.TextureHeight
	local bottom = self.Coordinates[self.Current][4] / self.TextureHeight
	self.Texture:SetTexCoord(left, right, top, bottom)
	self.Texture:Show()
	
	-- Cycle the textures to get a perceived randomness.
	self.Current = (self.Current % self.Number) + 1
end

-- Sets the background color.
function RandomBackground:SetColor(color)
	self.Texture:SetVertexColor(color[1], color[2], color[3])
end

-- Sets the texture path.
function RandomBackground:SetTexture(texture, width, height)
	self.Texture:SetTexture(texture)
	self.TextureWidth = width
	self.TextureHeight = height
end

-- Sets the texture coordinates.
function RandomBackground:SetCoordinates(coordinates)
	self.Coordinates = coordinates
	self.Number = table.getn(coordinates)
end

-- Sets the scale.
function RandomBackground:SetScale(x, y)
	self.ScaleX = x
	self.ScaleY = y
end